#ifdef OPENGL_ES
#extension GL_OES_standard_derivatives : enable
#ifdef GL_FRAGMENT_PRECISION_HIGH
precision highp float;
#else
precision mediump float;
#endif
#else
precision mediump float;
#endif

///////////////////////////////////////////////////////////
// Uniforms
uniform sampler2D u_texture;
uniform float u_n;	// p[^
uniform float u_block;
///////////////////////////////////////////////////////////
// Varyings
varying vec2 v_texCoord;
varying vec4 v_color;

// RGBYYIQւ̕ϊ
vec3 RGB2YIQ(vec3 rgb)
{
	rgb = clamp(rgb, 0.0, 1.0);
	return mat3(0.299, 0.587, 0.114, 0.596, -0.274, -0.322, 0.211, -0.523, 0.313) * rgb;
}

// YIQRGB̕ϊ
vec3 YIQ2RGB(vec3 yiq)
{
	vec3 rgb = mat3(1.0, 0.956, 0.621, 1.0, -0.272, -0.647, 1.0, -1.106, 1.703) * yiq;
	rgb = clamp(rgb, 0.0, 1.0);
	return rgb;
}

vec3 SampleYIQ(vec2 uv, float d)
{
	uv.x += d;
	return RGB2YIQ(texture2D(u_texture, uv).rgb);
}

void main()
{
	vec2 uv = v_texCoord;

	vec3 q = SampleYIQ(uv, 0.0);

	//float u_length = 2.0;
	//vec3 q = vec3(0.0);
	//q += texture2D(u_texture, vec2(uv.x - 4.0 * u_length, uv.y)).rgb * 0.05;
	//q += texture2D(u_texture, vec2(uv.x - 3.0 * u_length, uv.y)).rgb * 0.09;
	//q += texture2D(u_texture, vec2(uv.x - 2.0 * u_length, uv.y)).rgb * 0.12;
	//q += texture2D(u_texture, vec2(uv.x -       u_length, uv.y)).rgb * 0.15;
	//q += texture2D(u_texture, vec2(uv.x, uv.y)).rgb * 0.16;
	//q += texture2D(u_texture, vec2(uv.x +       u_length, uv.y)).rgb * 0.15;
	//q += texture2D(u_texture, vec2(uv.x + 2.0 * u_length, uv.y)).rgb * 0.12;
	//q += texture2D(u_texture, vec2(uv.x + 3.0 * u_length, uv.y)).rgb * 0.09;
	//q += texture2D(u_texture, vec2(uv.x + 4.0 * u_length, uv.y)).rgb * 0.05;

	// ubNmCY
	float f = 3.0 - mod(u_block, 3.0);
	if (uv.y > f && uv.y < f + 0.01) {
		uv.y = f;
	}

	// Bleeding
	for (int i = 0; i < 10; i++) {
		q.y += SampleYIQ(uv, -u_n * float(i)).y;
		q.z += SampleYIQ(uv, u_n * float(i)).z;
	}
	q.yz /= 10.00;

	// Fringing
	//float y1 = SampleYIQ(uv, -u_n).x;
	//float y2 = SampleYIQ(uv, u_n).x;
	//q.yz += y2 - y1;

	// Scanline
	float s = sin(uv.y *  500.0 * 3.1415 + u_n * 3.0);
	s = mix(1.0, (s + 1.0), 1.0);
	//s = mix(1.0, (s + 1.0) / 2.0, 1.0);

	vec3 c = YIQ2RGB(q * s);
	//
	//c.xyz += 0.2;

	// crt monitor
	vec2 m = v_texCoord * 2.0 - 1.0;
	vec2 o = abs(m.yx) / vec2(6.0, 4.0);
	m += m * o * o;
	m = abs(m);
	m.x = pow(m.x, 15.0);
	m.y = pow(m.y, 15.0);
	c.r = mix(c.r, 0.0, m.x + m.y);
	c.g = mix(c.g, 0.0, m.x + m.y);
	c.b = mix(c.b, 0.0, m.x + m.y);

	// ͂Â
	//vec2 u = v_texCoord;
	//u = 2.0 * u - 1.0;
	//c *= 1.0 - dot(u, u);

	gl_FragColor = vec4(c, 1.0);
}
